@@ -25,7 +25,7 @@ class IDrone(IRobot, abc.ABC):
 
     def _get_device(self, key, name):
         device_retriever = {
-            EnableableDevice.RECEIVER: self.getReceiver,
+            EnableableDevice.RECEIVER: self.getDevice,
             EnableableDevice.CAMERA: self.getCamera,
             EnableableDevice.INERTIAL_UNIT: self.getInertialUnit,
             EnableableDevice.GPS: self.getGPS,
